==> estateplat-common-1.2.3-20180514.060258-83-sources.jar: cn/gtmap/estateplat/model/server/core/BdcQlr.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
 * 不动产登记权利人
 *
 * @author <a href="mailto:shenjian@gtmap.cn">jane</a>
 * @version 1.0, 2015/11/1
 */
@Table(name = "bdc_qlr")
public class BdcQlr implements Serializable,BdcProid,InsertVo,Cloneable {
    @Id
    private String qlrid;//权利人主键

    private String proid;//项目id

    private String qlrmc;//权利人名称

    private String qlrsfzjzl;//权利人身份证件种类

    private String qlrzjh;//权利人证件号

    private String qlrtxdz;//权利人通讯地址

    private String qlryb;//权利人邮编

    private String qlrfddbr;//权利人法定代表人

    private String qlrfddbrdh;//权利人法定代表人电话

    private String qlrdlr;//权利人代理人

    private String qlrdlrdh;//权利人代理人电话

    private String qlrdljg;//权利人代理机构

    private String qlrlx;//权利人类型

    private String qlbl;//权利比例

    private String gyfs;//共有方式

    private String gyqk;//共有情况

    private String qlrxz;//权利人性质

    private String qlrlxdh;//权利人联系电话

    private String sshy;//所属行业

    private String bz;//备注

    private String sfczr;//是否持证

    private int sxh;//顺序号

    private String sfxs;//是否在证书权利人一栏显示

    private String xb;//性别

    private String qlrdlrzjzl;//代理人证件种类

    private  String qlrdlrzjh;//代理人证件号

    private  String qygyr;//其余共有人
    /**
     * @author <a href="mailto:zhangxing@gtmap.cn">zx</a>
     * @description 填写方式 1:手动修改2：身份证读取
     */
    private String txfs;

    private Integer fwtc;//房屋套次

    private String fwtcmx;//房屋套次明细

    /**
     * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
     * @description bdc_qlr表增加冗余字段qzysxlh、bdcqzh
     */
    private String qzysxlh; //权证印刷序列号

    private String bdcqzh; //不动产权证号

    public String getQzysxlh() {
        return qzysxlh;
    }

    public void setQzysxlh(String qzysxlh) {
        this.qzysxlh = qzysxlh;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public String getQlrid() {
        return qlrid;
    }

    public void setQlrid(String qlrid) {
        this.qlrid = qlrid;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getQlrsfzjzl() {
        return qlrsfzjzl;
    }

    public void setQlrsfzjzl(String qlrsfzjzl) {
        this.qlrsfzjzl = qlrsfzjzl;
    }

    public String getQlrzjh() {
        return qlrzjh;
    }

    public void setQlrzjh(String qlrzjh) {
        this.qlrzjh = qlrzjh;
    }

    public String getQlrtxdz() {
        return qlrtxdz;
    }

    public void setQlrtxdz(String qlrtxdz) {
        this.qlrtxdz = qlrtxdz;
    }

    public String getQlryb() {
        return qlryb;
    }

    public void setQlryb(String qlryb) {
        this.qlryb = qlryb;
    }

    public String getQlrfddbr() {
        return qlrfddbr;
    }

    public void setQlrfddbr(String qlrfddbr) {
        this.qlrfddbr = qlrfddbr;
    }

    public String getQlrfddbrdh() {
        return qlrfddbrdh;
    }

    public void setQlrfddbrdh(String qlrfddbrdh) {
        this.qlrfddbrdh = qlrfddbrdh;
    }

    public String getQlrdlr() {
        return qlrdlr;
    }

    public void setQlrdlr(String qlrdlr) {
        this.qlrdlr = qlrdlr;
    }

    public String getQlrdlrdh() {
        return qlrdlrdh;
    }

    public void setQlrdlrdh(String qlrdlrdh) {
        this.qlrdlrdh = qlrdlrdh;
    }

    public String getQlrdljg() {
        return qlrdljg;
    }

    public void setQlrdljg(String qlrdljg) {
        this.qlrdljg = qlrdljg;
    }

    public String getQlrlx() {
        return qlrlx;
    }

    public void setQlrlx(String qlrlx) {
        this.qlrlx = qlrlx;
    }

    public String getQlrxz() {
        return qlrxz;
    }

    public void setQlrxz(String qlrxz) {
        this.qlrxz = qlrxz;
    }

    public String getQlbl() {
        return qlbl;
    }

    public void setQlbl(String qlbl) {
        this.qlbl = qlbl;
    }

    public String getGyfs() {
        return gyfs;
    }

    public void setGyfs(String gyfs) {
        this.gyfs = gyfs;
    }

    public String getQlrlxdh() {
        return qlrlxdh;
    }

    public void setQlrlxdh(String qlrlxdh) {
        this.qlrlxdh = qlrlxdh;
    }


    public int getSxh() {
        return sxh;
    }

    public void setSxh(int sxh) {
        this.sxh = sxh;
    }

    public String getSfxs() {
        return sfxs;
    }

    public void setSfxs(String sfxs) {
        this.sfxs = sfxs;
    }

    public String getQlrmc() {
        return qlrmc;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public String getSshy() {
        return sshy;
    }

    public void setSshy(String sshy) {
        this.sshy = sshy;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getSfczr() {
        return sfczr;
    }

    public void setSfczr(String sfczr) {
        this.sfczr = sfczr;
    }

    public String getXb() {
        return xb;
    }

    public void setXb(String xb) {
        this.xb = xb;
    }

    public String getQlrdlrzjzl() {
        return qlrdlrzjzl;
    }

    public void setQlrdlrzjzl(String qlrdlrzjzl) {
        this.qlrdlrzjzl = qlrdlrzjzl;
    }

    public String getQlrdlrzjh() {
        return qlrdlrzjh;
    }

    public void setQlrdlrzjh(String qlrdlrzjh) {
        this.qlrdlrzjh = qlrdlrzjh;
    }

    public String getQygyr() {
        return qygyr;
    }

    public void setQygyr(String qygyr) {
        this.qygyr = qygyr;
    }

    public String getTxfs() {
        return txfs;
    }

    public void setTxfs(String txfs) {
        this.txfs = txfs;
    }

    public Integer getFwtc() {
        return fwtc;
    }

    public void setFwtc(Integer fwtc) {
        this.fwtc = fwtc;
    }

    public String getFwtcmx() {
        return fwtcmx;
    }

    public void setFwtcmx(String fwtcmx) {
        this.fwtcmx = fwtcmx;
    }
}

==> estateplat-common-1.2.3-20180523.065010-94-sources.jar: cn/gtmap/estateplat/model/server/core/BdcQlr.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * 不动产登记权利人
 *
 * @author <a href="mailto:shenjian@gtmap.cn">jane</a>
 * @version 1.0, 2015/11/1
 */
@Table(name = "bdc_qlr")
public class BdcQlr implements Serializable,BdcProid,InsertVo,Cloneable {
    @Id
    private String qlrid;//权利人主键

    private String proid;//项目id

    private String qlrmc;//权利人名称

    private String qlrsfzjzl;//权利人身份证件种类

    private String qlrzjh;//权利人证件号

    private String qlrtxdz;//权利人通讯地址

    private String qlryb;//权利人邮编

    private String qlrfddbr;//权利人法定代表人

    private String qlrfddbrdh;//权利人法定代表人电话

    private String qlrdlr;//权利人代理人

    private String qlrdlrdh;//权利人代理人电话

    private String qlrdljg;//权利人代理机构

    private String qlrlx;//权利人类型

    private String qlbl;//权利比例

    private String gyfs;//共有方式

    private String gyqk;//共有情况

    private String qlrxz;//权利人性质

    private String qlrlxdh;//权利人联系电话

    private String sshy;//所属行业

    private String bz;//备注

    private String sfczr;//是否持证

    private int sxh;//顺序号

    private String sfxs;//是否在证书权利人一栏显示

    private String xb;//性别

    private String qlrdlrzjzl;//代理人证件种类

    private  String qlrdlrzjh;//代理人证件号

    private  String qygyr;//其余共有人
    /**
     * @author <a href="mailto:zhangxing@gtmap.cn">zx</a>
     * @description 填写方式 1:手动修改2：身份证读取
     */
    private String txfs;

    private Integer fwtc;//房屋套次

    private String fwtcmx;//房屋套次明细

    /**
     * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
     * @description bdc_qlr表增加冗余字段qzysxlh、bdcqzh
     */
    private String qzysxlh; //权证印刷序列号

    private String bdcqzh; //不动产权证号
    //权利人证件有效开始日期
    private Date qlrzjyxkarq;
    //权利人证件有效结束日期
    private Date qlrzjyxjarq;

    public String getQzysxlh() {
        return qzysxlh;
    }

    public void setQzysxlh(String qzysxlh) {
        this.qzysxlh = qzysxlh;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public String getQlrid() {
        return qlrid;
    }

    public void setQlrid(String qlrid) {
        this.qlrid = qlrid;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getQlrsfzjzl() {
        return qlrsfzjzl;
    }

    public void setQlrsfzjzl(String qlrsfzjzl) {
        this.qlrsfzjzl = qlrsfzjzl;
    }

    public String getQlrzjh() {
        return qlrzjh;
    }

    public void setQlrzjh(String qlrzjh) {
        this.qlrzjh = qlrzjh;
    }

    public String getQlrtxdz() {
        return qlrtxdz;
    }

    public void setQlrtxdz(String qlrtxdz) {
        this.qlrtxdz = qlrtxdz;
    }

    public String getQlryb() {
        return qlryb;
    }

    public void setQlryb(String qlryb) {
        this.qlryb = qlryb;
    }

    public String getQlrfddbr() {
        return qlrfddbr;
    }

    public void setQlrfddbr(String qlrfddbr) {
        this.qlrfddbr = qlrfddbr;
    }

    public String getQlrfddbrdh() {
        return qlrfddbrdh;
    }

    public void setQlrfddbrdh(String qlrfddbrdh) {
        this.qlrfddbrdh = qlrfddbrdh;
    }

    public String getQlrdlr() {
        return qlrdlr;
    }

    public void setQlrdlr(String qlrdlr) {
        this.qlrdlr = qlrdlr;
    }

    public String getQlrdlrdh() {
        return qlrdlrdh;
    }

    public void setQlrdlrdh(String qlrdlrdh) {
        this.qlrdlrdh = qlrdlrdh;
    }

    public String getQlrdljg() {
        return qlrdljg;
    }

    public void setQlrdljg(String qlrdljg) {
        this.qlrdljg = qlrdljg;
    }

    public String getQlrlx() {
        return qlrlx;
    }

    public void setQlrlx(String qlrlx) {
        this.qlrlx = qlrlx;
    }

    public String getQlrxz() {
        return qlrxz;
    }

    public void setQlrxz(String qlrxz) {
        this.qlrxz = qlrxz;
    }

    public String getQlbl() {
        return qlbl;
    }

    public void setQlbl(String qlbl) {
        this.qlbl = qlbl;
    }

    public String getGyfs() {
        return gyfs;
    }

    public void setGyfs(String gyfs) {
        this.gyfs = gyfs;
    }

    public String getQlrlxdh() {
        return qlrlxdh;
    }

    public void setQlrlxdh(String qlrlxdh) {
        this.qlrlxdh = qlrlxdh;
    }


    public int getSxh() {
        return sxh;
    }

    public void setSxh(int sxh) {
        this.sxh = sxh;
    }

    public String getSfxs() {
        return sfxs;
    }

    public void setSfxs(String sfxs) {
        this.sfxs = sfxs;
    }

    public String getQlrmc() {
        return qlrmc;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public String getSshy() {
        return sshy;
    }

    public void setSshy(String sshy) {
        this.sshy = sshy;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getSfczr() {
        return sfczr;
    }

    public void setSfczr(String sfczr) {
        this.sfczr = sfczr;
    }

    public String getXb() {
        return xb;
    }

    public void setXb(String xb) {
        this.xb = xb;
    }

    public String getQlrdlrzjzl() {
        return qlrdlrzjzl;
    }

    public void setQlrdlrzjzl(String qlrdlrzjzl) {
        this.qlrdlrzjzl = qlrdlrzjzl;
    }

    public String getQlrdlrzjh() {
        return qlrdlrzjh;
    }

    public void setQlrdlrzjh(String qlrdlrzjh) {
        this.qlrdlrzjh = qlrdlrzjh;
    }

    public String getQygyr() {
        return qygyr;
    }

    public void setQygyr(String qygyr) {
        this.qygyr = qygyr;
    }

    public String getTxfs() {
        return txfs;
    }

    public void setTxfs(String txfs) {
        this.txfs = txfs;
    }

    public Integer getFwtc() {
        return fwtc;
    }

    public void setFwtc(Integer fwtc) {
        this.fwtc = fwtc;
    }

    public String getFwtcmx() {
        return fwtcmx;
    }

    public void setFwtcmx(String fwtcmx) {
        this.fwtcmx = fwtcmx;
    }

    public Date getQlrzjyxkarq() {
        return qlrzjyxkarq;
    }

    public void setQlrzjyxkarq(Date qlrzjyxkarq) {
        this.qlrzjyxkarq = qlrzjyxkarq;
    }

    public Date getQlrzjyxjarq() {
        return qlrzjyxjarq;
    }

    public void setQlrzjyxjarq(Date qlrzjyxjarq) {
        this.qlrzjyxjarq = qlrzjyxjarq;
    }
}
